==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_projdisplaypage.php <==
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font>&nbsp;--&nbsp;<font face="<?= $font_1 ?>" size="2"><?= $project["project_title"] ?></font></td>
</tr>
<tr>
<!-- project info -->
<td valign="top">
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2"><?= $project["description"] ?>&nbsp;
	<? if (empty($access_level) && $member_id) {
    echo "Want to join this project? <a href=\"/project/" . $project_name . "/projjoin.php\">Click Here</a> to request to join the development team.";
    } else if (empty($member_id)) {
    echo "Want to join this project? GreatBridge.org <a href=\"/member/memjoin.php\">members</a> can request to join a project development team.";
    }
    ?>
	</font>
        </td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project Modules</b></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/bugs/buglist.php"><b>View bugs</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/task/tasklist.php"><b>View tasks</b></a> (<?= $num_tasks ?>)</font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/viewcvs/"><b>View Web CVS</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/patch/patchlist.php"><b>View Patches</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/download/download.php"><b>View Downloads</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="http://www.greatbridge.org/mailman/listinfo/<?= $project_name ?>"><b>Mailing Lists</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr>
	<td><font face="<?= $font_1 ?>" size="1">Note: You may access CVS from the command line at...<br><i>:pserver:<?= empty($member_name)?"anonymous":$member_name ?>@www.greatbridge.org:/usr/local/cvsroot/<?= $project_name ?><? if( empty($member_name)) { ?><br>The password for anonymous login is 'anonymous'<? } ?></i></font></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project Members</b></font></td>
	</tr>
	<? while(list(,$member) = @each($members)){ ?>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/member/memprofile?<?= $member["member_id"] ?>"><b><?= $member["member_name"]?></b></a>&nbsp;--&nbsp;<?= ucfirst($roles[$member["role_id"]]) ?></font></td>
	</tr>
	<? } ?>
	</table>
</td>
<!-- spacer -->
<td><img src="<?= $image_path ?>/shim.gif" width="10" height="1"></td>
<!-- survey - news -->
<? if(!empty($news_list)) { ?>
<td valign="top" bgcolor="<?= $color_4 ?>" width="150">
<img src="<?= $image_path ?>/shim.gif" width="150" height="1"><br>
	<!-- news -->
	<table cellpadding="1" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_2 ?>">
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project News</b></font></td>
	</tr>
	<? while(list(,$projnews) = @each($news_list)) { ?>	
	<tr bgcolor="<?= $color_2 ?>">
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<b><?= $projnews["headline"] ?></b>
	<br>
	<?= $projnews["body"] ?><br>(<a href="/project/<?= $project_name ?>/news/newsfull.php?news_id=<?= $projnews["news_id"] ?>">full story...</a>)
	<br>
	<p align="right"><i><a href="mailto:<?= $projnews["email"] ?>"><?= $projnews["member_name"] ?></a>&nbsp;:&nbsp;<?= date("m/d/Y",strtotime($projnews["submit_date"])) ?></i></p>
	</font>
	</td>
	</tr>
	<? } ?>
	</table>
</td>
<? } else { ?>
<td valign="top" bgcolor="<?= $color_2 ?>" width="1">
&nbsp;
</td>
<? } ?>
</tr>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_projdisplaypage.php <==
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font>&nbsp;--&nbsp;<font face="<?= $font_1 ?>" size="2"><?= $project["project_title"] ?></font></td>
</tr>
<tr>
<!-- project info -->
<td valign="top">
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2"><?= $project["description"] ?>&nbsp;
	<? if (empty($access_level) && $member_id) {
    echo "Want to join this project? <a href=\"/project/" . $project_name . "/projjoin.php\">Click Here</a> to request to join the development team.";
    } else if (empty($member_id)) {
    echo "Want to join this project? <?= $official_name ?> <a href=\"/member/memjoin.php\">members</a> can request to join a project development team.";
    }
    ?>
	</font>
        </td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project Modules</b></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/bugs/buglist.php"><b>View bugs</b></a> (<?= $num_bugs ?>)</font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/task/tasklist.php"><b>View tasks</b></a> (<?= $num_tasks ?>)</font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/viewcvs/"><b>View Web CVS</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/patch/patchlist.php"><b>View Patches</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/download/download.php"><b>View Downloads</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="http://www.greatbridge.org/mailman/listinfo/<?= $project_name ?>"><b>Mailing Lists</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/errata.php"><b>Errata</b></a></font></td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr>
	<td><font face="<?= $font_1 ?>" size="1">Note: You may access CVS from the command line at...<br><i>:pserver:<?= empty($member_name)?"anonymous":$member_name ?>@www.greatbridge.org:/usr/local/cvsroot/<?= $project_name ?><? if( empty($member_name)) { ?><br>The password for anonymous login is 'anonymous'<? } ?></i></font></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project Members</b></font></td>
	</tr>
	<? while(list(,$member) = @each($members)){ ?>
	<tr>
	<td><img src="<?= $image_path ?>/gray_bullet.gif" width="16" height="10">&nbsp;<font face="<?= $font_1 ?>" size="2"><a href="/member/memprofile?<?= $member["member_id"] ?>"><b><?= $member["member_name"]?></b></a>&nbsp;--&nbsp;<?= ucfirst($roles[$member["role_id"]]) ?></font></td>
	</tr>
	<? } ?>
	</table>
</td>
<!-- spacer -->
<td><img src="<?= $image_path ?>/shim.gif" width="10" height="1"></td>
<!-- survey - news -->
<? if(!empty($news_list)) { ?>
<td valign="top" bgcolor="<?= $color_4 ?>" width="150">
<img src="<?= $image_path ?>/shim.gif" width="150" height="1"><br>
	<!-- news -->
	<table cellpadding="1" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_2 ?>">
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Project News</b></font></td>
	</tr>
	<? while(list(,$projnews) = @each($news_list)) { ?>	
	<tr bgcolor="<?= $color_2 ?>">
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<b><?= $projnews["headline"] ?></b>
	<br>
	<?= $projnews["body"] ?><br>(<a href="/project/<?= $project_name ?>/news/newsfull.php?news_id=<?= $projnews["news_id"] ?>">full story...</a>)
	<br>
	<p align="right"><i><a href="mailto:<?= $projnews["email"] ?>"><?= $projnews["member_name"] ?></a>&nbsp;:&nbsp;<?= date("m/d/Y",strtotime($projnews["submit_date"])) ?></i></p>
	</font>
	</td>
	</tr>
	<? } ?>
	</table>
</td>
<? } else { ?>
<td valign="top" bgcolor="<?= $color_2 ?>" width="1">
&nbsp;
</td>
<? } ?>
</tr>
</table>
